@@ -1,3 +1,5 @@
+#   -*- coding: utf-8 -*-
+#
 #   This file is part of PyBuilder
 #
 #   Copyright 2011-2014 PyBuilder Team
@@ -17,7 +19,7 @@
 from pybuilder.core import task, use_plugin
 from pybuilder.errors import BuildFailedException
 
-import subprocess
+from subprocess import PIPE, Popen
 
 use_plugin("core")
 
@@ -62,15 +64,12 @@ def _log_quoted_output(logger, output_type, output, phase):
 
 def run_command(phase, project, logger):
     command_line = project.get_property('%s_command' % phase)
+
     if not command_line:
         return
 
-    process_handle = subprocess.Popen(
-        command_line,
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
-        shell=True)
-    (stdout, stderr) = process_handle.communicate()
+    process_handle = Popen(command_line, stdout=PIPE, stderr=PIPE, shell=True)
+    stdout, stderr = process_handle.communicate()
     process_return_code = process_handle.returncode
 
     _write_command_report(project,
