@@ -20,6 +20,8 @@ from __future__ import print_function
 
 __author__ = "Alexander Metzner"
 
+import sys
+
 from pybuilder.core import before, after, task, description, use_plugin, init
 from pybuilder.errors import BuildFailedException
 from pybuilder.utils import assert_can_execute, execute_command, mkdir
@@ -84,7 +86,11 @@ def install_dependency(logger, project, dependency):
     logger.info("Installing dependency '%s'%s", dependency.name, " from %s" % dependency.url if dependency.url else "")
     log_file = project.expand_path("$dir_install_logs", dependency.name)
 
-    pip_command_line = "pip install {0}'{1}'".format(build_pip_install_options(project, dependency), as_pip_argument(dependency))
+    if sys.platform.startswith("win"):
+        dependency = as_pip_argument(dependency)
+    else:
+        dependency = "'{0}'".format(as_pip_argument(dependency))
+    pip_command_line = "pip install {0}{1}".format(build_pip_install_options(project, dependency), dependency)
     exit_code = execute_command(pip_command_line, log_file, shell=True)
     if exit_code != 0:
         if project.get_property("verbose"):
